@@ -22,10 +22,9 @@
 #include <unistd.h>
 #include <stdlib.h>
 
-#include <qfile.h>
-#include <qdir.h>
+#include <QFile>
+#include <QDir>
 
-#include <kapplication.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
@@ -45,9 +44,9 @@ void error_handler(int err_sig);
 
 int main( int argc, char** argv )
 {
-  KAboutData aboutData( "kdat", I18N_NOOP("KDat"), 
-    KDAT_VERSION, description, KAboutData::License_GPL, 
-    "(c) 1999-2000, Sean Vyain; 2001-2002 Lawrence Widman");
+  KAboutData aboutData( "kdat", 0, ki18n("KDat"), 
+    KDAT_VERSION, ki18n(description), KAboutData::License_GPL, 
+    ki18n("(c) 1999-2000, Sean Vyain; 2001-2002 Lawrence Widman"));
 
   /* 2002-01-28 LEW: so we can dump core if we want to */
   // KCrash::setCrashHandler(0);  // this is supposed to work, but it doesn't
@@ -56,7 +55,7 @@ int main( int argc, char** argv )
     char *newarg;
     if( ( newarg = (char *)malloc( strlen("--nocrashhandler") + 1 ) ) == NULL )
       {
-	KMessageBox::sorry(NULL, i18n("Can't allocate memory in kdat"));
+	KMessageBox::sorry(NULL, i18n("Cannot allocate memory in kdat"));
         exit(1);
       }
     strcpy( newarg, "--nocrashhandler" );
@@ -73,7 +72,7 @@ int main( int argc, char** argv )
   /* 2002-01-28 LEW */
 
   KCmdLineArgs::init( argc, argv, &aboutData );
-  aboutData.addAuthor( "Lawrence Widman", 0, "kdat@cardiothink.com");
+  aboutData.addAuthor( ki18n("Lawrence Widman"), KLocalizedString(), "kdat@cardiothink.com");
 //  KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
   KApplication app;
   
@@ -86,7 +85,7 @@ int main( int argc, char** argv )
   signal(SIGSEGV, error_handler);
   signal(SIGTERM, error_handler);   
 
-  if ( app.isRestored() && KDatMainWindow::canBeRestored( 1 ) ) {
+  if ( app.isSessionRestored() && KDatMainWindow::canBeRestored( 1 ) ) {
     KDatMainWindow::getInstance()->restore( 1 );
   } else {
     KDatMainWindow::getInstance()->show();
