@@ -44,12 +44,3 @@ void KWirelessInterface::setEssid(QString newEssid)
   essid = newEssid;
 }
 
-QString KWirelessInterface::getKeyType()
-{
-  return keyType;
-}
-
-void KWirelessInterface::setKeyType(QString type)
-{
-    keyType = type;
-}
