@@ -24,32 +24,35 @@
 ** Bug reports and questions can be sent to kde-devel@kde.org
 */
 
-
 #ifndef FINDF_H
 #define FINDF_H
 
-#include "../config.h"
-
 // Standard Headers
 #include <stdio.h>
 
 // Qt Headers
-#include <qdir.h>
-#include <qwidget.h>
-#include <qframe.h>
-#include <qlabel.h>
-#include <qfiledialog.h>
-#include <qgroupbox.h>
-#include <qcheckbox.h>
-#include <qlayout.h>
+#include <QtCore/QDir>
+#include <QtGui/QWidget>
+#include <QtGui/QLabel>
+#include <Qt3Support/Q3FileDialog>
+#include <Qt3Support/Q3GroupBox>
+#include <QtGui/QCheckBox>
+#include <QtGui/QLayout>
+//Added by qt3to4:
+#include <QtGui/QDragEnterEvent>
+#include <QtGui/QPixmap>
+#include <QtGui/QVBoxLayout>
+#include <QtGui/QHBoxLayout>
+#include <QtGui/QResizeEvent>
+#include <QtGui/QDropEvent>
+#include <QtGui/QPushButton>
 
 // KDE headers
-#include <kapplication.h>
 #include <kmenubar.h>
-#include <klistview.h>
-#include <kdialogbase.h>
+#include <k3listview.h>
+#include <kdialog.h>
 
-class FindF : public KDialogBase
+class FindF : public KDialog
 {
   Q_OBJECT
 
@@ -60,7 +63,7 @@ public:
   void resizeEvent(QResizeEvent *);
   void dropEvent(QDropEvent *);
   void dragEnterEvent(QDragEnterEvent* e);
-  void checkSearchAll();
+  void disableSearchAll();
 
   
 private:
@@ -68,12 +71,13 @@ private:
   // Do the actual search
 
   QLineEdit *value;
-  QListView *tab;
+  Q3ListView *tab;
   QVBoxLayout* vl;
   QVBoxLayout* vtop, vf;
 
   QHBoxLayout* hb;
   QCheckBox *searchAll;
+  QPushButton *updateFiles;
   QPixmap tick;
 
 signals:
@@ -83,7 +87,7 @@ signals:
 public slots:
   void done_slot();
   void ok_slot();
-  void search(QListViewItem *);
+  void search(Q3ListViewItem *);
   void textChanged ( const QString & text);
 
 };
