@@ -25,8 +25,8 @@
 */
 #include "ksvmiscconfig.h"
 
-#include <qgroupbox.h>
-#include <qlayout.h>
+#include <q3groupbox.h>
+#include <QLayout>
 
 #include <kdialog.h>
 
@@ -34,7 +34,7 @@
  *  Constructs a KSVMiscConfig which is a child of 'parent', with the 
  *  name 'name' and widget flags set to 'f' 
  */
-KSVMiscConfig::KSVMiscConfig( QWidget* parent,  const char* name, WFlags fl )
+KSVMiscConfig::KSVMiscConfig( QWidget* parent,  const char* name, Qt::WFlags fl )
     : MiscConfiguration( parent, name, fl )
 {
   mSpacer->setFixedHeight (KDialog::spacingHint());
