@@ -17,19 +17,19 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
-** Bug reports and questions can be sent to kde-devel@kde.org
+** Bug reports and questions can be sent to <kde-devel@kde.org>
 */
 
 #include "Details.moc"
-#include <qlayout.h>
+#include <QLayout>
 #include <qhbox.h>
 #include <qwhatsthis.h>
-#include <qlabel.h>
+#include <QLabel>
 #include <ui.h>
 
 Details::Details(liloimage *lilo, QWidget *parent, const char *name, WFlags f):QDialog(parent, name, true, f)
@@ -113,7 +113,7 @@ Details::Details(liloimage *lilo, QWidget *parent, const char *name, WFlags f):Q
 			vga->setCurrentItem(1);
 		else
 			for(int i=0; i<vga->count(); i++) {
-				if(vga->text(i).contains("(" + mode + ")")) {
+				if(vga->text(i).contains('(' + mode + ')')) {
 					vga->setCurrentItem(i);
 					break;
 				}
